DEFAULT_API_URL = "https://ai.insightfinder.com"

# API Endpoints
CHATBOT_ENDPOINT = "api/external/v1/chatbot/stream-with-type"
EVALUATION_ENDPOINT = "api/external/v1/evaluation/bias-hallu"
SAFETY_EVALUATION_ENDPOINT = "api/external/v1/evaluation/safety"
TRACE_PROJECT_NAME_ENDPOINT = "api/external/v1/chatbot/get-trace-project-name-v2"